@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Algorithm::Kelly;
-$Algorithm::Kelly::VERSION = '0.01';
+$Algorithm::Kelly::VERSION = '0.02';
 # ABSTRACT: calculates the fraction of of your bankroll to bet using the Kelly formula
 
 BEGIN
@@ -43,7 +43,7 @@ Algorithm::Kelly - calculates the fraction of of your bankroll to bet using the
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head2 SYNOPSIS
 
@@ -52,9 +52,11 @@ version 0.01
 
     say optimal_f(0.5, 2); # 0.25
 
+=head2 FUNCTIONS
+
 =head2 optimal_f ($probability, $payoff)
 
-Returns the optimal L<fraction|https://en.wikipedia.org/wiki/Kelly_criterion> of bankroll to wager, using the Kelly Criterion, given the C<$probability> and C<$payoff>. Payoff should be the net odds of the wager, so the value of 3-to-1 would be 3. The C<fraction()> sub is exported by default.
+Returns the optimal L<fraction|https://en.wikipedia.org/wiki/Kelly_criterion> of bankroll to wager, using the Kelly Criterion, given the C<$probability> and C<$payoff>. Payoff should be the net odds of the wager, so the value of 3-to-1 would be 3. The C<optimal_f()> sub is exported by default.
 
 =head1 AUTHOR
 
